==> jc-1.4.0.tar.gz: javax/swing/InternalFrameFocusTraversalPolicy.c <==
// public abstract class javax.swing.InternalFrameFocusTraversalPolicy

// class file dependencies
// @dep_class d547e55bb64f2ca8 java_awt_Component
// @dep_class aa7caa0df83b76f6 java_awt_FocusTraversalPolicy
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 3cd22a3f5d3a5e41 javax_swing_InternalFrameFocusTraversalPolicy
// @dep_class dc092f455615c9f0 javax_swing_JInternalFrame

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header javax_swing_InternalFrameFocusTraversalPolicy
// @dep_header javax_swing_JInternalFrame

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "javax/swing/InternalFrameFocusTraversalPolicy.h"
#include "javax/swing/JInternalFrame.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_javax_swing_InternalFrameFocusTraversalPolicy$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_javax_swing_InternalFrameFocusTraversalPolicy$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_javax_swing_InternalFrameFocusTraversalPolicy$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_javax_swing_InternalFrameFocusTraversalPolicy$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_swing_InternalFrameFocusTraversalPolicy$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_swing_InternalFrameFocusTraversalPolicy$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_swing_InternalFrameFocusTraversalPolicy$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_InternalFrameFocusTraversalPolicy, _init$52f4ad9f2989aeee);

void
_jc_javax_swing_InternalFrameFocusTraversalPolicy$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_javax_swing_InternalFrameFocusTraversalPolicy$object *this)
{
	struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(49);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.awt.Component getInitialComponent(javax.swing.JInternalFrame)
//

static _jc_linenum _jc_javax_swing_InternalFrameFocusTraversalPolicy$linenum_table$getInitialComponent$4f44bd9e24dac6b8[];

static const unsigned char _jc_javax_swing_InternalFrameFocusTraversalPolicy$param_ptypes$getInitialComponent$4f44bd9e24dac6b8[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_javax_swing_InternalFrameFocusTraversalPolicy$param_types$getInitialComponent$4f44bd9e24dac6b8[] = {
	&_jc_javax_swing_JInternalFrame$type
};

_jc_method _jc_javax_swing_InternalFrameFocusTraversalPolicy$method_info$getInitialComponent$4f44bd9e24dac6b8 = {
	.name=			"getInitialComponent",
	.signature=		"(Ljavax/swing/JInternalFrame;)Ljava/awt/Component;",
	.class=			&_jc_javax_swing_InternalFrameFocusTraversalPolicy$type,
	.param_types=		&_jc_javax_swing_InternalFrameFocusTraversalPolicy$param_types$getInitialComponent$4f44bd9e24dac6b8,
	.return_type=		&_jc_java_awt_Component$type,
	.param_ptypes=		&_jc_javax_swing_InternalFrameFocusTraversalPolicy$param_ptypes$getInitialComponent$4f44bd9e24dac6b8,
	.signature_hash=	_JC_JLONG(0x4f44bd9e24dac6b8),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_swing_InternalFrameFocusTraversalPolicy$method$getInitialComponent$4f44bd9e24dac6b8,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$vtable, javax_swing_InternalFrameFocusTraversalPolicy.getInitialComponent$4f44bd9e24dac6b8) / sizeof(void *),
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_swing_InternalFrameFocusTraversalPolicy$linenum_table$getInitialComponent$4f44bd9e24dac6b8
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_InternalFrameFocusTraversalPolicy, getInitialComponent$4f44bd9e24dac6b8);

_jc_java_awt_Component$object *
_jc_javax_swing_InternalFrameFocusTraversalPolicy$method$getInitialComponent$4f44bd9e24dac6b8(_jc_env *const env, _jc_javax_swing_InternalFrameFocusTraversalPolicy$object *this, _jc_javax_swing_JInternalFrame$object *param0)
{
	struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$object *r0;
	struct _jc_javax_swing_JInternalFrame$object *r1;
	struct _jc_java_awt_Component$object *r2;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(53);				// 0
	r2 = _JC_INVOKE_VIRTUAL(env, java_awt_FocusTraversalPolicy, getDefaultComponent$67de0147fc890905, r0, r1);
	return r2;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_javax_swing_InternalFrameFocusTraversalPolicy$methods[] = {
	&_jc_javax_swing_InternalFrameFocusTraversalPolicy$method_info$_init$52f4ad9f2989aeee,
	&_jc_javax_swing_InternalFrameFocusTraversalPolicy$method_info$getInitialComponent$4f44bd9e24dac6b8
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_javax_swing_InternalFrameFocusTraversalPolicy$instanceof_hash_bucket_65[] = {
	&_jc_javax_swing_InternalFrameFocusTraversalPolicy$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_swing_InternalFrameFocusTraversalPolicy$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_swing_InternalFrameFocusTraversalPolicy$instanceof_hash_bucket_118[] = {
	&_jc_java_awt_FocusTraversalPolicy$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_javax_swing_InternalFrameFocusTraversalPolicy$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[65]=	_jc_javax_swing_InternalFrameFocusTraversalPolicy$instanceof_hash_bucket_65,
	[113]=	_jc_javax_swing_InternalFrameFocusTraversalPolicy$instanceof_hash_bucket_113,
	[118]=	_jc_javax_swing_InternalFrameFocusTraversalPolicy$instanceof_hash_bucket_118
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_javax_swing_InternalFrameFocusTraversalPolicy$class_depends[] = {
	{ "java/awt/Component",	_JC_JLONG(0xd547e55bb64f2ca8) },
	{ "java/awt/FocusTraversalPolicy",	_JC_JLONG(0xaa7caa0df83b76f6) },
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "javax/swing/JInternalFrame",	_JC_JLONG(0xdc092f455615c9f0) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_javax_swing_InternalFrameFocusTraversalPolicy$vtype _jc_javax_swing_InternalFrameFocusTraversalPolicy$type = {
    .type= {
	.name=			"javax/swing/InternalFrameFocusTraversalPolicy",
	.superclass=		&_jc_java_awt_FocusTraversalPolicy$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		18,
		.hash=			_JC_JLONG(0x3cd22a3f5d3a5e41),
		.source_file=		"InternalFrameFocusTraversalPolicy.java",
		.instance_size=		sizeof(_jc_javax_swing_InternalFrameFocusTraversalPolicy$refs) + sizeof(_jc_javax_swing_InternalFrameFocusTraversalPolicy$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_javax_swing_InternalFrameFocusTraversalPolicy$methods) / sizeof(*_jc_javax_swing_InternalFrameFocusTraversalPolicy$methods),
		.methods=		_jc_javax_swing_InternalFrameFocusTraversalPolicy$methods,
		.instanceof_hash_table=	_jc_javax_swing_InternalFrameFocusTraversalPolicy$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_javax_swing_InternalFrameFocusTraversalPolicy$class_depends) / sizeof(*_jc_javax_swing_InternalFrameFocusTraversalPolicy$class_depends),
		.class_depends=		_jc_javax_swing_InternalFrameFocusTraversalPolicy$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_awt_FocusTraversalPolicy= {
	    .getComponentAfter$e959ccefc51f77d4=
		&_jc_java_awt_FocusTraversalPolicy$method$getComponentAfter$e959ccefc51f77d4,
	    .getComponentBefore$67b5e67dbd8ccef1=
		&_jc_java_awt_FocusTraversalPolicy$method$getComponentBefore$67b5e67dbd8ccef1,
	    .getDefaultComponent$67de0147fc890905=
		&_jc_java_awt_FocusTraversalPolicy$method$getDefaultComponent$67de0147fc890905,
	    .getFirstComponent$ca27cc2e0962c11a=
		&_jc_java_awt_FocusTraversalPolicy$method$getFirstComponent$ca27cc2e0962c11a,
	    .getInitialComponent$c34e7fe182e355e3=
		&_jc_java_awt_FocusTraversalPolicy$method$getInitialComponent$c34e7fe182e355e3,
	    .getLastComponent$626704694883b4fc=
		&_jc_java_awt_FocusTraversalPolicy$method$getLastComponent$626704694883b4fc,
	},
	.javax_swing_InternalFrameFocusTraversalPolicy= {
	    .getInitialComponent$4f44bd9e24dac6b8=
		&_jc_javax_swing_InternalFrameFocusTraversalPolicy$method$getInitialComponent$4f44bd9e24dac6b8,
	},
    }
};

==> jc-1.4.5.tar.gz: javax/swing/InternalFrameFocusTraversalPolicy.c <==
// public abstract class javax.swing.InternalFrameFocusTraversalPolicy

// class file dependencies
// @dep_class 5a2bf6e9db456f42 java_awt_Component
// @dep_class aa7caa0df83b76f6 java_awt_FocusTraversalPolicy
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 3cd22a3f5d3a5e41 javax_swing_InternalFrameFocusTraversalPolicy
// @dep_class dc092f455615c9f0 javax_swing_JInternalFrame

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header javax_swing_InternalFrameFocusTraversalPolicy
// @dep_header javax_swing_JInternalFrame

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "javax/swing/InternalFrameFocusTraversalPolicy.h"
#include "javax/swing/JInternalFrame.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_javax_swing_InternalFrameFocusTraversalPolicy$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_javax_swing_InternalFrameFocusTraversalPolicy$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_javax_swing_InternalFrameFocusTraversalPolicy$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_javax_swing_InternalFrameFocusTraversalPolicy$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_swing_InternalFrameFocusTraversalPolicy$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_swing_InternalFrameFocusTraversalPolicy$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_swing_InternalFrameFocusTraversalPolicy$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_InternalFrameFocusTraversalPolicy, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_javax_swing_InternalFrameFocusTraversalPolicy$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_javax_swing_InternalFrameFocusTraversalPolicy$object *this)
{
	struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(49);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.awt.Component getInitialComponent(javax.swing.JInternalFrame)
//

static _jc_linenum _jc_javax_swing_InternalFrameFocusTraversalPolicy$linenum_table$getInitialComponent$4f44bd9e24dac6b8[];

static const unsigned char _jc_javax_swing_InternalFrameFocusTraversalPolicy$param_ptypes$getInitialComponent$4f44bd9e24dac6b8[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_javax_swing_InternalFrameFocusTraversalPolicy$param_types$getInitialComponent$4f44bd9e24dac6b8[] = {
	&_jc_javax_swing_JInternalFrame$type
};

_jc_method _jc_javax_swing_InternalFrameFocusTraversalPolicy$method_info$getInitialComponent$4f44bd9e24dac6b8 = {
	.name=			"getInitialComponent",
	.signature=		"(Ljavax/swing/JInternalFrame;)Ljava/awt/Component;",
	.class=			&_jc_javax_swing_InternalFrameFocusTraversalPolicy$type,
	.param_types=		&_jc_javax_swing_InternalFrameFocusTraversalPolicy$param_types$getInitialComponent$4f44bd9e24dac6b8,
	.return_type=		&_jc_java_awt_Component$type,
	.param_ptypes=		&_jc_javax_swing_InternalFrameFocusTraversalPolicy$param_ptypes$getInitialComponent$4f44bd9e24dac6b8,
	.signature_hash=	_JC_JLONG(0x4f44bd9e24dac6b8),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_swing_InternalFrameFocusTraversalPolicy$method$getInitialComponent$4f44bd9e24dac6b8,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$vtable, javax_swing_InternalFrameFocusTraversalPolicy.getInitialComponent$4f44bd9e24dac6b8) / sizeof(void *),
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_swing_InternalFrameFocusTraversalPolicy$linenum_table$getInitialComponent$4f44bd9e24dac6b8
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_InternalFrameFocusTraversalPolicy, getInitialComponent$4f44bd9e24dac6b8);

_jc_java_awt_Component$object * _JC_JCNI_ATTR
_jc_javax_swing_InternalFrameFocusTraversalPolicy$method$getInitialComponent$4f44bd9e24dac6b8(_jc_env *const env, _jc_javax_swing_InternalFrameFocusTraversalPolicy$object *this, _jc_javax_swing_JInternalFrame$object *param0)
{
	struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$object *r0;
	struct _jc_javax_swing_JInternalFrame$object *r1;
	struct _jc_java_awt_Component$object *r2;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(53);				// 0
	r2 = _JC_INVOKE_VIRTUAL(env, java_awt_FocusTraversalPolicy, getDefaultComponent$67de0147fc890905, r0, r1);
	return r2;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_javax_swing_InternalFrameFocusTraversalPolicy$methods[] = {
	&_jc_javax_swing_InternalFrameFocusTraversalPolicy$method_info$_init$52f4ad9f2989aeee,
	&_jc_javax_swing_InternalFrameFocusTraversalPolicy$method_info$getInitialComponent$4f44bd9e24dac6b8
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_javax_swing_InternalFrameFocusTraversalPolicy$instanceof_hash_bucket_65[] = {
	&_jc_javax_swing_InternalFrameFocusTraversalPolicy$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_swing_InternalFrameFocusTraversalPolicy$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_swing_InternalFrameFocusTraversalPolicy$instanceof_hash_bucket_118[] = {
	&_jc_java_awt_FocusTraversalPolicy$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_javax_swing_InternalFrameFocusTraversalPolicy$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[65]=	_jc_javax_swing_InternalFrameFocusTraversalPolicy$instanceof_hash_bucket_65,
	[101]=	_jc_javax_swing_InternalFrameFocusTraversalPolicy$instanceof_hash_bucket_101,
	[118]=	_jc_javax_swing_InternalFrameFocusTraversalPolicy$instanceof_hash_bucket_118
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_javax_swing_InternalFrameFocusTraversalPolicy$class_depends[] = {
	{ "java/awt/Component",	_JC_JLONG(0x5a2bf6e9db456f42) },
	{ "java/awt/FocusTraversalPolicy",	_JC_JLONG(0xaa7caa0df83b76f6) },
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "javax/swing/JInternalFrame",	_JC_JLONG(0xdc092f455615c9f0) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_javax_swing_InternalFrameFocusTraversalPolicy$vtype _jc_javax_swing_InternalFrameFocusTraversalPolicy$type = {
    .type= {
	.name=			"javax/swing/InternalFrameFocusTraversalPolicy",
	.superclass=		&_jc_java_awt_FocusTraversalPolicy$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		18,
		.hash=			_JC_JLONG(0x3cd22a3f5d3a5e41),
		.source_file=		"InternalFrameFocusTraversalPolicy.java",
		.instance_size=		sizeof(_jc_javax_swing_InternalFrameFocusTraversalPolicy$refs) + sizeof(_jc_javax_swing_InternalFrameFocusTraversalPolicy$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_javax_swing_InternalFrameFocusTraversalPolicy$methods) / sizeof(*_jc_javax_swing_InternalFrameFocusTraversalPolicy$methods),
		.methods=		_jc_javax_swing_InternalFrameFocusTraversalPolicy$methods,
		.instanceof_hash_table=	_jc_javax_swing_InternalFrameFocusTraversalPolicy$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_javax_swing_InternalFrameFocusTraversalPolicy$class_depends) / sizeof(*_jc_javax_swing_InternalFrameFocusTraversalPolicy$class_depends),
		.class_depends=		_jc_javax_swing_InternalFrameFocusTraversalPolicy$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_awt_FocusTraversalPolicy= {
	    .getComponentAfter$e959ccefc51f77d4=
		&_jc_java_awt_FocusTraversalPolicy$method$getComponentAfter$e959ccefc51f77d4,
	    .getComponentBefore$67b5e67dbd8ccef1=
		&_jc_java_awt_FocusTraversalPolicy$method$getComponentBefore$67b5e67dbd8ccef1,
	    .getDefaultComponent$67de0147fc890905=
		&_jc_java_awt_FocusTraversalPolicy$method$getDefaultComponent$67de0147fc890905,
	    .getFirstComponent$ca27cc2e0962c11a=
		&_jc_java_awt_FocusTraversalPolicy$method$getFirstComponent$ca27cc2e0962c11a,
	    .getInitialComponent$c34e7fe182e355e3=
		&_jc_java_awt_FocusTraversalPolicy$method$getInitialComponent$c34e7fe182e355e3,
	    .getLastComponent$626704694883b4fc=
		&_jc_java_awt_FocusTraversalPolicy$method$getLastComponent$626704694883b4fc,
	},
	.javax_swing_InternalFrameFocusTraversalPolicy= {
	    .getInitialComponent$4f44bd9e24dac6b8=
		&_jc_javax_swing_InternalFrameFocusTraversalPolicy$method$getInitialComponent$4f44bd9e24dac6b8,
	},
    }
};
